@@ -1,9 +1,11 @@
 package App::realpath;
 
+use strict;
+
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-16'; # DATE
+our $DATE = '2021-11-26'; # DATE
 our $DIST = 'App-realpath'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 1;
 # ABSTRACT: Print the resolved (absolute) path
@@ -20,7 +22,7 @@ App::realpath - Print the resolved (absolute) path
 
 =head1 VERSION
 
-This document describes version 0.003 of App::realpath (from Perl distribution App-realpath), released on 2021-07-16.
+This document describes version 0.004 of App::realpath (from Perl distribution App-realpath), released on 2021-11-26.
 
 =head1 DESCRIPTION
 
@@ -34,14 +36,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-realpa
 
 Source repository is at L<https://github.com/perlancar/perl-App-realpath>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-realpath>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<App::relpath>
@@ -52,11 +46,36 @@ L<App::quickabspath>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2019 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2019 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-realpath>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
